/*
 * oma-ds-agent
 * Copyright (c) 2012 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef IN_DATASTORE_INFO_VCARD_H_
#define IN_DATASTORE_INFO_VCARD_H_

#define VCARD_TYPE						"text/x-vcard"
#define VCARD_VERSION					"2.1"

typedef enum {
	VCARD_FIELD_BEGIN = 10,
	VCARD_FIELD_END,
	VCARD_FIELD_VERSION,
	VCARD_FIELD_FN,
	VCARD_FIELD_N,
	VCARD_FIELD_NICKNAME,
	VCARD_FIELD_PHOTO,
	VCARD_FIELD_BDAY,
	VCARD_FIELD_ADR,
	VCARD_FIELD_LABEL,
	VCARD_FIELD_TEL,
	VCARD_FIELD_EMAIL,
	VCARD_FIELD_TITLE,
	VCARD_FIELD_ROLE,
	VCARD_FIELD_ORG,
	VCARD_FIELD_NOTE,
	VCARD_FIELD_REV,
	VCARD_FIELD_UID,
	VCARD_FIELD_URL,
	VCARD_FIELD_X_ANNIVERSARY,
	VCARD_FIELD_X_IRMC_LUID,

} vcard_field_e;

typedef enum {
	VCARD_FIELD_ADR_DOM = 100,
	VCARD_FIELD_ADR_INTL,
	VCARD_FIELD_ADR_HOME,
	VCARD_FIELD_ADR_WORK,
	VCARD_FIELD_ADR_POSTAL,
	VCARD_FIELD_ADR_PARCEL,
	VCARD_FIELD_ADR_PREF,

} vcard_field_adr_sub_e;

typedef enum {
	VCARD_FIELD_TEL_HOME = 200,
	VCARD_FIELD_TEL_MSG,
	VCARD_FIELD_TEL_WORK,
	VCARD_FIELD_TEL_VOICE,
	VCARD_FIELD_TEL_FAX,
	VCARD_FIELD_TEL_CELL,
	VCARD_FIELD_TEL_VIDEO,
	VCARD_FIELD_TEL_PAGER,
	VCARD_FIELD_TEL_BBS,
	VCARD_FIELD_TEL_MODEM,
	VCARD_FIELD_TEL_CAR,
	VCARD_FIELD_TEL_ISDN,
	VCARD_FIELD_TEL_PCS,
	VCARD_FIELD_TEL_PREF,

} vcard_field_tel_sub_e;

typedef enum {
	VCARD_FIELD_EMAIL_HOME = 300,
	VCARD_FIELD_EMAIL_WORK,
	VCARD_FIELD_EMAIL_PREF,

} vcard_field_email_sub_e;

typedef struct vcard_field_list vcard_field_list_s;
struct vcard_field_list {
	int field_enum;
	char *field_name;
};

static vcard_field_list_s vcard_field_list[] = {
	{VCARD_FIELD_BEGIN, "BEGIN"},
	{VCARD_FIELD_END, "END"},
	{VCARD_FIELD_VERSION, "VERSION"},
	{VCARD_FIELD_FN, "FN"},
	{VCARD_FIELD_N, "N"},
	{VCARD_FIELD_NICKNAME, "NICKNAME"},
	{VCARD_FIELD_PHOTO, "PHOTO"},
	{VCARD_FIELD_BDAY, "BDAY"},
	{VCARD_FIELD_ADR, "ADR"},
	{VCARD_FIELD_LABEL, "LABEL"},
	{VCARD_FIELD_TEL, "TEL"},
	{VCARD_FIELD_EMAIL, "EMAIL"},
	{VCARD_FIELD_TITLE, "TITLE"},
	{VCARD_FIELD_ROLE, "ROLE"},
	{VCARD_FIELD_ORG, "ORG"},
	{VCARD_FIELD_NOTE, "NOTE"},
	{VCARD_FIELD_REV, "REV"},
	{VCARD_FIELD_UID, "UID"},
	{VCARD_FIELD_URL, "URL"},
	{VCARD_FIELD_X_ANNIVERSARY, "X-ANNIVERSARY"},
	{VCARD_FIELD_X_IRMC_LUID, "X-IRMC-LUID"}
};

static vcard_field_list_s vcard_field_list_adr[] = {
	{VCARD_FIELD_ADR_DOM, "DOM"},
	{VCARD_FIELD_ADR_INTL, "INTL"},
	{VCARD_FIELD_ADR_HOME, "HOME"},
	{VCARD_FIELD_ADR_WORK, "WORK"},
	{VCARD_FIELD_ADR_POSTAL, "POSTAL"},
	{VCARD_FIELD_ADR_PARCEL, "PARCEL"},
	{VCARD_FIELD_ADR_PREF, "PREF"}
};

static vcard_field_list_s vcard_field_list_tel[] = {
	{VCARD_FIELD_TEL_HOME, "HOME"},
	{VCARD_FIELD_TEL_MSG, "MSG"},
	{VCARD_FIELD_TEL_WORK, "WORK"},
	{VCARD_FIELD_TEL_VOICE, "VOICE"},
	{VCARD_FIELD_TEL_FAX, "FAX"},
	{VCARD_FIELD_TEL_CELL, "CELL"},
	{VCARD_FIELD_TEL_VIDEO, "VIDEO"},
	{VCARD_FIELD_TEL_PAGER, "PAGER"},
	{VCARD_FIELD_TEL_BBS, "BBS"},
	{VCARD_FIELD_TEL_MODEM, "MODEM"},
	{VCARD_FIELD_TEL_CAR, "CAR"},
	{VCARD_FIELD_TEL_ISDN, "ISDN"},
	{VCARD_FIELD_TEL_PCS, "PCS"},
	{VCARD_FIELD_TEL_PREF, "PREF"}
};

static vcard_field_list_s vcard_field_list_email[] = {
	{VCARD_FIELD_EMAIL_HOME, "HOME"},
	{VCARD_FIELD_EMAIL_WORK, "WORK"},
	{VCARD_FIELD_EMAIL_PREF, "PREF"}
};

static vcard_field_list_s vcard_field_list_begin_end[] = {
	{-1, "VCARD"}
};

static vcard_field_list_s vcard_field_list_version[] = {
	{-1, VCARD_VERSION}
};

#endif				/* IN_DATASTORE_INFO_VCARD_H_ */
